@@ -1,6 +1,6 @@
 #' @keywords WRCC
 #' @export
-#' @title Obtain WRCC Data and Parse into Dataframe
+#' @title Obtain WRCC Data and Parse into Tibbler
 #' @param startdate desired start date (integer or character representing YYYYMMDD[HH])
 #' @param enddate desired end date (integer or character representing YYYYMMDD[HH])
 #' @param unitID station identifier (will be upcased)
@@ -8,9 +8,9 @@
 #' @param baseUrl base URL for data queries
 #' @param saveFile optional filename where raw CSV will be written
 #' @param flagAndKeep flag, rather then remove, bad data during the QC process
-#' @return Raw dataframe of WRCC data.
+#' @return Raw tibble of WRCC data.
 #' @description Obtains monitor data from a WRCC webservice and converts
-#' it into a quality controlled, metadata enhanced "raw" dataframe
+#' it into a quality controlled, metadata enhanced "raw" tibble
 #' ready for use with all \code{raw_~} functions.
 #' 
 #' Steps involved include:
@@ -25,7 +25,7 @@
 #' 
 #' @examples
 #' \dontrun{
-#' df <- wrcc_createRawDataframe(20150701, 20150930, unitID='SM16')
+#' tbl <- wrcc_createRawDataframe(20150701, 20150930, unitID='SM16')
 #' }
 #' 
 #' @note The downloaded CSV may be saved to a local file by providing an argument to the \code{saveFile} parameter.
@@ -38,8 +38,8 @@
 #' 
 #' @references \href{http://www.wrcc.dri.edu/cgi-bin/smoke.pl}{Fire Cache Smoke Monitoring Archive}
 
-wrcc_createRawDataframe <- function(startdate=20100101,
-                                    enddate=strftime(lubridate::now(),"%Y%m%d",tz="GMT"),
+wrcc_createRawDataframe <- function(startdate=strftime(lubridate::now(),"%Y010100",tz="UTC"),
+                                    enddate=strftime(lubridate::now(),"%Y%m%d23",tz="UTC"),
                                     unitID=NULL,
                                     clusterDiameter=1000,
                                     baseUrl="http://www.wrcc.dri.edu/cgi-bin/wea_list2.pl",
@@ -72,20 +72,20 @@ wrcc_createRawDataframe <- function(startdate=20100101,
     # NOTE:  Processing continues even if we fail to write the local file
   }
   
-  # Read csv raw data into a dataframe
+  # Read csv raw data into a tibble
   logger.debug("Parsing data ...")
-  df <- wrcc_parseData(fileString)
+  tbl <- wrcc_parseData(fileString)
   
   # Add source of raw data
-  df$rawSource <- "WRCC"
+  tbl$rawSource <- "WRCC"
   
-  # Apply monitor-appropriate QC to the dataframe
+  # Apply monitor-appropriate QC to the tibble
   logger.debug("Applying QC logic ...")
-  df <- wrcc_qualityControl(df, flagAndKeep=flagAndKeep)
+  tbl <- wrcc_qualityControl(tbl, flagAndKeep=flagAndKeep)
   
   # Add clustering information to identify unique deployments
   logger.debug("Clustering ...")
-  df <- addClustering(df, lonVar='GPSLon', latVar='GPSLat', clusterDiameter=clusterDiameter, flagAndKeep=flagAndKeep)
+  tbl <- addClustering(tbl, lonVar='GPSLon', latVar='GPSLat', clusterDiameter=clusterDiameter, flagAndKeep=flagAndKeep)
   
   # Rearrange columns to put QCFlag_* parameters at end if they exist
   if ( flagAndKeep ) {
@@ -101,11 +101,11 @@ wrcc_createRawDataframe <- function(startdate=20100101,
                         "QCFlag_badDateAndTime",
                         "QCFlag_duplicateHr")
     # TODO: add intersection check here to remove those that do not exist in data
-    df_QC <- df[,QC_columnNames]
-    df_nonQC <- df[,-(which(names(df) %in% QC_columnNames))]
-    df <- cbind(df_nonQC,df_QC)
+    tbl_QC <- tbl[,QC_columnNames]
+    tbl_nonQC <- tbl[,-(which(names(tbl) %in% QC_columnNames))]
+    tbl <- cbind(tbl_nonQC,tbl_QC)
   }
   
-  return(df)
+  return(tbl)
   
 }
